# WriteAuthorizationModelRequest


## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**type_definitions** | [**list[TypeDefinition]**](TypeDefinition.md) |  | 
**schema_version** | **str** |  | 
**conditions** | [**dict[str, Condition]**](Condition.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


